# Documentation

This is the source of the FlatBuffers documentation, that is served at
https://flatbuffers.dev.


## Local Building

The documentation can be built and served locally during development, see <https://flatbuffers.dev/contributing/#local-development> for full details.

__tl;dr__

Install:

```
pip install mkdocs-material
pip install mkdocs-redirects
```

Build and Serve:

```
mkdocs serve -f docs/mkdocs.yml
```
